@@ -1,6 +1,6 @@
 # infra
 from .interface import AsyncRunnable, LazyLoadable
-from .interface import MessageTypes, ChannelTypes, ChannelPrivacyTypes, EventTypes
+from .interface import MessageTypes, ChannelTypes, ChannelPrivacyTypes, EventTypes, GuildMuteTypes
 from .cert import Cert
 from .receiver import Receiver, WebhookReceiver, WebsocketReceiver
 from .requester import HTTPRequester
@@ -10,10 +10,9 @@ from .client import Client
 # concepts
 from .role import Role
 from .user import User
-from .channel import Channel, PublicTextChannel, PrivateChannel, PublicChannel, public_channel_factory
+from .channel import Channel, PublicTextChannel, PrivateChannel, PublicChannel
 from .guild import Guild
 from .context import Context
 from .message import RawMessage, Message, PublicMessage, PrivateMessage, Event
-
 # extensions
 from .bot import *
