@@ -56,7 +56,9 @@ class Bot(AsyncRunnable):
         if not token and not cert:
             raise ValueError('require token or cert')
         self._init_client(cert or Cert(token=token), client, gate, out, compress, port, route)
-        self.client.register(MessageTypes.TEXT, self._make_msg_handler())
+        msg_handler=self._make_msg_handler()
+        self.client.register(MessageTypes.TEXT, msg_handler)
+        self.client.register(MessageTypes.KMD, msg_handler)
         self.client.register(MessageTypes.SYS, self._make_event_handler())
 
         self.command = CommandManager()
